
# Slot: status


status of the element

URI: [linkml:status](https://w3id.org/linkml/status)


## Domain and Range

[Element](Element.md) &#8594;  <sub>0..1</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [SlotDefinition](SlotDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | bibo:status |
| **Examples:** | | Example(value='bibo:draft', description=None) |

